Test coverage report: enquiry.simple_translate

# enquiry.simple_translate: 4 total statements, 0.0% covered

Generated: Tue 2013-02-05 19:07 SGT

Source file: /Users/martin/Repos/django-enquiry/enquiry/simple_translate.py

Stats: 0 executed, 2 missed, 2 excluded, 9 ignored

1. `"""Registration of models of the ``enquiry`` app."""`
2. `from simple_translation.translation_pool import translation_pool`
3. ``
4. `from enquiry.models import (`
5. `Answer,`
6. `AnswerTrans,`
7. `Enquiry,`
8. `EnquiryTrans,`
9. `)`
10. ``
11. ``
12. `translation_pool.register_translation(Answer, AnswerTrans)`
13. `translation_pool.register_translation(Enquiry, EnquiryTrans)`